import { Injectable } from '@angular/core';

import { Actions, createEffect, ofType } from '@ngrx/effects';
import { Store, select } from '@ngrx/store';
import { TranslateService } from '@ngx-translate/core';

import { NGXLogger } from 'ngx-logger';
import { userNotification } from './actions';
import { map, tap, withLatestFrom } from 'rxjs/operators';

import { SnackBarService } from '@ucap-webmessenger/ui';

import { UserInfoUpdateType } from '@ucap-webmessenger/protocol-info';
import { LoginResponse } from '@ucap-webmessenger/protocol-authentication';
import * as AuthenticationStore from '@app/store/account/authentication';
import { UserInfo } from '@ucap-webmessenger/protocol-room';

@Injectable()
export class Effects {
  userNotification$ = createEffect(
    () => {
      return this.actions$.pipe(
        ofType(userNotification),
        withLatestFrom(
          this.store.pipe(
            select(
              (state: any) =>
                state.account.authentication.loginRes as LoginResponse
            )
          )
        ),
        // map(action => action.noti),
        tap(([action, loginRes]) => {
          if (action.noti.SENDER_SEQ !== loginRes.SENDER_SEQ) {
            return;
          }

          if (action.noti.info === '') {
            this.snackBarService.open(
              this.translateService.instant(
                'profile.errors.failToSyncProfileImage'
              ),
              '',
              {
                duration: 3000,
                verticalPosition: 'bottom'
              }
            );
            return;
          }
          let userInfo = {} as any;

          switch (action.noti.type) {
            case UserInfoUpdateType.Image:
              userInfo = {
                ...loginRes.userInfo,
                profileImageFile: action.noti.info
              };
              break;
            case UserInfoUpdateType.Intro:
              userInfo = {
                ...loginRes.userInfo,
                intro: action.noti.info
              };

              break;
            case UserInfoUpdateType.StatusMessage1:
              break;
            case UserInfoUpdateType.StatusMessage2:
              break;
            case UserInfoUpdateType.StatusMessage3:
              break;
            default:
              break;
          }

          this.store.dispatch(
            AuthenticationStore.updateLoginRes({
              loginRes: {
                ...loginRes,
                userInfo
              }
            })
          );
        })
      );
    },
    { dispatch: false }
  );

  constructor(
    private actions$: Actions,
    private store: Store<any>,
    private snackBarService: SnackBarService,
    private translateService: TranslateService,
    private logger: NGXLogger
  ) {}
}
