import {
  Component,
  OnInit,
  Inject,
  ViewChild,
  ElementRef
} from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';

export interface ConfirmDialogData {
  title: string;
  message?: string;
  html?: string;
  hideAction?: boolean;
}

export interface ConfirmDialogResult {
  choice: boolean;
  isClose: boolean;
}

@Component({
  selector: 'ucap-ui-confirm-dialog',
  templateUrl: './confirm.dialog.component.html',
  styleUrls: ['./confirm.dialog.component.scss']
})
export class ConfirmDialogComponent implements OnInit {
  @ViewChild('messageContainer', { static: true })
  messageContainer: ElementRef;

  hideAction = false;

  constructor(
    public dialogRef: MatDialogRef<ConfirmDialogComponent, ConfirmDialogResult>,
    @Inject(MAT_DIALOG_DATA) public data: ConfirmDialogData
  ) {}

  ngOnInit(): void {
    if (!!this.data.html) {
      this.messageContainer.nativeElement.innerHTML = this.data.html;
    }
    if (!!this.data.hideAction) {
      this.hideAction = this.data.hideAction;
    }
  }

  onClickChoice(state: number): void {
    let isChoice = false;
    let closeChoice = false;

    if (state === 1) {
      isChoice = false;
    } else if (state === 2) {
      isChoice = true;
    } else {
      closeChoice = true;
    }

    this.dialogRef.close({
      choice: isChoice,
      isClose: closeChoice
    });
  }
}
